==> ejc-purchasingmanagement-impl-3.0.0-20220424.052451-26-sources.jar: com/ejianc/business/purchasingmanagement/bean/PurchasedetilEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;


import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;


/**
 * 采购运输信息明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_purchasedetil")
public class PurchasedetilEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchasetransportation_id")
    private Long purchasetransportationId; // 主表主键
    @TableField(value="materialplan_id")
    private Long materialplanId; // 定料计划主键
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输车辆主键
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输车辆
    @TableField(value="delivery_quantity")
    private BigDecimal deliveryQuantity; // 发货数量
    @TableField(value="distance")
    private BigDecimal distance; // 运距
    @TableField(value="material_id")
    private Long materialId; // 原材类主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="material_name")
    private String materialName; // 原材类名称
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 运输单价
    @TableField(value="number_plate")
    private String numberPlate; // 车牌号
    @TableField(value="delivery_time")
    private Date deliveryTime; // 发货时间
    @TableField(value="status")
    private Integer status; // 是否收货(1:是,0:否)
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="tare_weight")
    private BigDecimal tareWeight;    //皮重

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getDeliveryQuantity() {
        return deliveryQuantity;
    }

    public void setDeliveryQuantity(BigDecimal deliveryQuantity) {
        this.deliveryQuantity = deliveryQuantity;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }

    public Long getPurchasetransportationId() {
        return purchasetransportationId;
    }

    public void setPurchasetransportationId(Long purchasetransportationId) {
        this.purchasetransportationId = purchasetransportationId;
    }
    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(Date deliveryTime) {
        this.deliveryTime = deliveryTime;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    
}

==> ejc-purchasingmanagement-impl-3.0.0-20220511.150614-65-sources.jar: com/ejianc/business/purchasingmanagement/bean/PurchasedetilEntity.java <==
package com.ejianc.business.purchasingmanagement.bean;

import java.util.Date;
import java.math.*;


import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;


/**
 * 采购运输信息明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_purchasingmanagement_purchasedetil")
public class PurchasedetilEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="purchasetransportation_id")
    private Long purchasetransportationId; // 主表主键
    @TableField(value="materialplan_id")
    private Long materialplanId; // 定料计划主键
    @TableField(value="supplierinfo_id")
    private Long supplierinfoId; // 供应商基本档案主键
    @TableField(value="shippers_vehicle_id")
    private Long shippersVehicleId; // 运输车辆主键
    @TableField(value="shippers_vehicle_name")
    private String shippersVehicleName; // 运输车辆
    @TableField(value="delivery_quantity")
    private BigDecimal deliveryQuantity; // 发货数量
    @TableField(value="distance")
    private BigDecimal distance; // 运距
    @TableField(value="material_id")
    private Long materialId; // 原材类主键
    @TableField(value="supplierinfo_name")
    private String supplierinfoName; // 供应商基本档案名称
    @TableField(value="material_name")
    private String materialName; // 原材类名称
    @TableField(value="unit_price")
    private BigDecimal unitPrice; // 运输单价
    @TableField(value="number_plate")
    private String numberPlate; // 车牌号
    @TableField(value="delivery_time")
    private Date deliveryTime; // 发货时间
    @TableField(value="status")
    private Integer status; // 是否收货(1:是,0:否)
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="tare_weight")
    private BigDecimal tareWeight;    //皮重

    @TableField(value="phone_number")
    private String phoneNumber; // 手机号
    @TableField(value="driver")
    private String driver; // 司机
    @TableField(value="receipt_quantity")
    private BigDecimal receiptQuantity; // 收货数量
    @TableField(value="receipt_time")
    private Date receiptTime; // 收货时间

    public BigDecimal getReceiptQuantity() {
        return receiptQuantity;
    }

    public void setReceiptQuantity(BigDecimal receiptQuantity) {
        this.receiptQuantity = receiptQuantity;
    }

    public Date getReceiptTime() {
        return receiptTime;
    }

    public void setReceiptTime(Date receiptTime) {
        this.receiptTime = receiptTime;
    }

    public String getDriver() {
        return driver;
    }

    public void setDriver(String driver) {
        this.driver = driver;
    }

    public String getPhoneNumber() {
        return phoneNumber;
    }

    public void setPhoneNumber(String phoneNumber) {
        this.phoneNumber = phoneNumber;
    }

    public BigDecimal getTareWeight() {
        return tareWeight;
    }

    public void setTareWeight(BigDecimal tareWeight) {
        this.tareWeight = tareWeight;
    }

    public BigDecimal getDeliveryQuantity() {
        return deliveryQuantity;
    }

    public void setDeliveryQuantity(BigDecimal deliveryQuantity) {
        this.deliveryQuantity = deliveryQuantity;
    }

    public BigDecimal getDistance() {
        return distance;
    }

    public void setDistance(BigDecimal distance) {
        this.distance = distance;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public String getShippersVehicleName() {
        return shippersVehicleName;
    }

    public void setShippersVehicleName(String shippersVehicleName) {
        this.shippersVehicleName = shippersVehicleName;
    }

    public Long getPurchasetransportationId() {
        return purchasetransportationId;
    }

    public void setPurchasetransportationId(Long purchasetransportationId) {
        this.purchasetransportationId = purchasetransportationId;
    }
    public Long getMaterialplanId() {
        return materialplanId;
    }

    public void setMaterialplanId(Long materialplanId) {
        this.materialplanId = materialplanId;
    }
    public Long getSupplierinfoId() {
        return supplierinfoId;
    }

    public void setSupplierinfoId(Long supplierinfoId) {
        this.supplierinfoId = supplierinfoId;
    }
    public Long getShippersVehicleId() {
        return shippersVehicleId;
    }

    public void setShippersVehicleId(Long shippersVehicleId) {
        this.shippersVehicleId = shippersVehicleId;
    }

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }
    public String getSupplierinfoName() {
        return supplierinfoName;
    }

    public void setSupplierinfoName(String supplierinfoName) {
        this.supplierinfoName = supplierinfoName;
    }
    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }
    public BigDecimal getUnitPrice() {
        return unitPrice;
    }

    public void setUnitPrice(BigDecimal unitPrice) {
        this.unitPrice = unitPrice;
    }
    public String getNumberPlate() {
        return numberPlate;
    }

    public void setNumberPlate(String numberPlate) {
        this.numberPlate = numberPlate;
    }
    public Date getDeliveryTime() {
        return deliveryTime;
    }

    public void setDeliveryTime(Date deliveryTime) {
        this.deliveryTime = deliveryTime;
    }
    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
    
}
